@@ -17,9 +17,9 @@ author = "Your Name"
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    "m2r2",
     "nbsphinx",
     "nbsphinx_link",
+    "sphinx_mdinclude",
     "sphinx.ext.autodoc",
     "sphinx_rtd_theme",
 ]
